API Reference
=============


.. autoclass:: klay.Circuit

    .. automethod:: nb_nodes

    .. automethod:: nb_root_nodes

    .. automethod:: true_node

    .. automethod:: false_node

    .. automethod:: literal_node

    .. automethod:: and_node

    .. automethod:: or_node

    .. automethod:: set_root

    .. automethod:: remove_unused_nodes

    .. automethod:: add_sdd

    .. automethod:: add_sdd_from_file

    .. automethod:: add_d4_from_file

    .. automethod:: to_torch_module

    .. automethod:: to_jax_function
